/*
 * Copyright (C) 2011 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.providers.contacts;

import android.content.Context;

import java.util.Locale;

/**
 * A version of {@link ProfileProvider} that performs all operations synchronously.
 */
public class SynchronousProfileProvider extends ProfileProvider {

    private static ProfileDatabaseHelper sDbHelper;

    public SynchronousProfileProvider(ContactsProvider2 delegate) {
        super(delegate);
    }

    @Override
    protected ProfileDatabaseHelper newDatabaseHelper(final Context context) {
        if (sDbHelper == null) {
            sDbHelper = ProfileDatabaseHelper.getNewInstanceForTest(context,
                    TestUtils.getProfileDatabaseFilename(getContext()));
        }
        return sDbHelper;
    }

    @Override
    protected Locale getLocale() {
        return Locale.US;
    }
}
